# 📦 CHANGELOG

All versions are documented in this file.

---

## [1.0.0] - 2025-05-19

### Added
- First stable release of the `eones` library.
- Unified parser for `str`, `dict`, and `datetime`.
- Timezone support using `ZoneInfo`.
- Truncation, aggregation, comparison, and range methods.
- Optional integrations for `Django`, `SQLAlchemy`, and `Serializers`.

### Changed
- Centralized interface using the `Eones` class.

---

## History

This project is designed to be minimalist, cross-platform, and 100% based on Python’s standard library.
